@@ -86,7 +86,7 @@
 #define KGLOBALACCEL_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCEL_NO_DEPRECATED
-#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55800
+#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef KGLOBALACCEL_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x55800
+#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
@@ -127,6 +127,12 @@
 #else
 #  define KGLOBALACCEL_DEPRECATED_VERSION_5_9(text)
 #endif
+
+#if KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE >= 0x55a00
+#  define KGLOBALACCEL_DEPRECATED_VERSION_5_90(text) KGLOBALACCEL_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KGLOBALACCEL_DEPRECATED_VERSION_5_90(text)
+#endif
 #define KGLOBALACCEL_DEPRECATED_VERSION_4(minor, text)      KGLOBALACCEL_DEPRECATED_VERSION_4_##minor(text)
 #define KGLOBALACCEL_DEPRECATED_VERSION_5(minor, text)      KGLOBALACCEL_DEPRECATED_VERSION_5_##minor(text)
 #define KGLOBALACCEL_DEPRECATED_VERSION(major, minor, text) KGLOBALACCEL_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
@@ -193,7 +199,7 @@
 #define KGLOBALACCEL_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCEL_NO_DEPRECATED
-#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55800
+#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef KGLOBALACCEL_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0
@@ -203,7 +209,7 @@
 #  ifdef KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x55800
+#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
@@ -234,6 +240,12 @@
 #else
 #  define KGLOBALACCEL_DEPRECATED_VERSION_5_9(text)
 #endif
+
+#if KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE >= 0x55a00
+#  define KGLOBALACCEL_DEPRECATED_VERSION_5_90(text) KGLOBALACCEL_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KGLOBALACCEL_DEPRECATED_VERSION_5_90(text)
+#endif
 #define KGLOBALACCEL_DEPRECATED_VERSION_4(minor, text)      KGLOBALACCEL_DEPRECATED_VERSION_4_##minor(text)
 #define KGLOBALACCEL_DEPRECATED_VERSION_5(minor, text)      KGLOBALACCEL_DEPRECATED_VERSION_5_##minor(text)
 #define KGLOBALACCEL_DEPRECATED_VERSION(major, minor, text) KGLOBALACCEL_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
